=================
Django Flickrsets
=================

**Reusable Django application to synchronize Flickr sets**.

**The application is currently not ready for production use. If you still want 
to deploy it on a production server, do it at your own risk.**

**Please, be cool with Flickr API.**
 
For instructions on how to install and use this application, and on what it 
provides, take a look in the ``docs/`` directory.

To generate the documentation, you should have `Sphinx`_ installed on your
system and run the following commands::

    git clone git@github.com:gillesfabio/django-flickrsets.git
    cd django-flickrsets/docs
    make html

Open ``django-flickrsets/docs/_build/html/index.html`` in your browser.

You can also `browse`_ this documentation online.

**Screenshot**:

.. image:: http://dl.dropbox.com/u/176040/django-flickrsets-example.png

.. _Sphinx: http://sphinx.pocoo.org/
.. _browse: http://gillesfabio.github.com/django-flickrsets/
